@@ -6,7 +6,7 @@
 #              a PATH.
 # Author:      Sergio Talens-Oliag <sto@debian.org>
 # Copyright:   (c) 2006 Sergio Talens-Oliag <sto@debian.org>
-# SVN Id:      $Id: ssft.sh 65 2006-03-20 16:18:21Z sto $
+# SVN Id:      $Id: ssft.sh 73 2006-12-22 18:06:11Z sto $
 # 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -208,17 +208,22 @@ unset -f ssft_sh_fhs_test
 # Description: print the name of the preferred frontend, but don't set it
 
 ssft_choose_frontend() {
+  _l_frontend=""
   if [ -n "$DISPLAY" ]; then
-    if [ -x "`which zenity`" ]; then
-      echo "zenity"
-    elif [ -x "`which kdialog`" ]; then
-      echo "kdialog"
+    if [ -x "`which zenity 2> /dev/null`" ]; then
+      _l_frontend="zenity"
+    elif [ -x "`which kdialog 2> /dev/null`" ]; then
+      _l_frontend="kdialog"
     fi
-  elif [ -x "`which dialog`" ]; then
-    echo "dialog"
-  else
-    echo "text"
   fi
+  if [ -z "$_l_frontend" ]; then
+    if [ -x "`which dialog`" ]; then
+      _l_frontend="dialog"
+    else
+      _l_frontend="text"
+    fi
+  fi
+  echo "$_l_frontend"
 }
 
 # Function: ssft_print_text_title TITLE
@@ -1124,4 +1129,4 @@ ssft_show_file() {
 }
 
 # ------
-# SVN Id: $Id: ssft.sh 65 2006-03-20 16:18:21Z sto $
+# SVN Id: $Id: ssft.sh 73 2006-12-22 18:06:11Z sto $
